@@ -28,10 +28,10 @@ Rcpp::NumericMatrix rcpp_genecont(const arma::ivec& numSire, const arma::ivec& n
     nDam  = numDam.at(i);
     /*Rprintf("i=%d\n",i);*/
     
-    if(nSire | nDam){
+    if((nSire>0) | (nDam>0)){
       nP = ((nSire<nDam)?nDam:nSire);
       for(j=0; (numAnc.at(j)<=nP)&(j<NAnc); j++){
-        pCont = ((nSire)?(GeneCont.at(nSire-1, j)):0.0) + ((nDam)?(GeneCont.at(nDam-1,  j)):0.0);
+        pCont = ((nSire>0)?(GeneCont.at(nSire-1, j)):0.0) + ((nDam>0)?(GeneCont.at(nDam-1,  j)):0.0);
         if(pCont>0){GeneCont.at(i, j) = 0.5*pCont;}
       }
     }
